﻿using Borepin.Base;
using Borepin.Model;
using Borepin.Service.BFFH;
using Borepin.Service.Connections;
using Prism.Commands;
using Prism.Navigation;
using System;
using System.Threading.Tasks;
using System.Windows.Input;

namespace Borepin.PageModel.AddServerProcess
{
    public class LoginPasswordPageModel : PageModelBase
    {
        #region Private Properties
        private readonly IBFFHService _BFFHService;
        private readonly IConnectionService _ConnectionService;
        #endregion

        #region Constructors
        public LoginPasswordPageModel(INavigationService navigationService, IBFFHService bffhService, IConnectionService connectionService) : base(navigationService)
        {
            _BFFHService = bffhService;
            _ConnectionService = connectionService;

            AuthenticateCommand = new DelegateCommand(async () => await AuthenticateCommandExecuted());

            Task.Run(LoadData);
        }
        #endregion

        #region LoadData
        public override async Task LoadData()
        {
            IsBusy = true;

            IsBusy = false;
            await Task.CompletedTask;
        }
        #endregion

        #region Properties
        private string _Username;
        public string Username
        {
            get => _Username;
            set => SetProperty(ref _Username, value);
        }

        private string _Password;
        public string Password
        {
            get => _Password;
            set => SetProperty(ref _Password, value);
        }
        #endregion

        #region Commands
        private ICommand _AuthenticateCommand;
        public ICommand AuthenticateCommand
        {
            get => _AuthenticateCommand;
            set => SetProperty(ref _AuthenticateCommand, value);
        }

        private async Task AuthenticateCommandExecuted()
        {
            Connection connection_update = _BFFHService.ActiveConnection;

            connection_update.Username = Username;

            await _BFFHService.Authenticate(connection_update, Password).ConfigureAwait(false);

            try
            {
                await _ConnectionService.AddConnection(_BFFHService.ActiveConnection);
            }
            catch (ArgumentException)
            {

            }

            await _ConnectionService.LogConnect(_BFFHService.ActiveConnection);

            var result = await _NavigationService.NavigateAsync("/MainPage/NavigationPage/MachineListPage");

            if (!result.Success)
            {
                System.Diagnostics.Debugger.Break();
            }
        }
        #endregion

        #region INavigationAware
        public override void OnNavigatedFrom(INavigationParameters parameters)
        {

        }

        public override void OnNavigatedTo(INavigationParameters parameters)
        {
            IsBusy = true;
            Task.Run(LoadData);
        }
        #endregion
    }
}