﻿using Borepin.Base;
using Prism.Commands;
using Prism.Navigation;
using System.Threading.Tasks;
using System.Windows.Input;
using FabAccessAPI.Schema;
using Borepin.Service.BFFH;
using static FabAccessAPI.Schema.MachineSystem;
using Borepin.Model;

namespace Borepin.PageModel
{
    public class MachinePageModel : PageModelBase
    {
        #region Private Properties
        private readonly IBFFHService _BFFHService;
        private string _Name;
        private Machine _Machine;
        #endregion

        #region Contructors
        public MachinePageModel(INavigationService navigationService, IBFFHService bffhService) : base(navigationService)
        {
            _BFFHService = bffhService;

            UseMachineCommand = new DelegateCommand(UseMachineCommandExecuted);
            GiveBackMachineCommand = new DelegateCommand(GiveBackMachineCommandExecuted);
        }
        #endregion

        #region LoadData
        public override async Task LoadData()
        {
            IsBusy = true;

            IMachineSystem machineSystem = await _BFFHService.GetMachineSystemInterface();

            IInfoInterface info = await machineSystem.Info();

            _Machine = (await info.GetMachine(_Name)).Item1;
            MachineItem = new MachineVisualize(_Machine);
            MachineItem.LoadData();

            IsBusy = false;
        }
        #endregion

        #region Properties
        private MachineVisualize _MachineItem;
        public MachineVisualize MachineItem
        {
            get => _MachineItem;
            set => SetProperty(ref _MachineItem, value);
        }
        #endregion

        #region Commands
        private ICommand _UseMachineCommand;

        public ICommand UseMachineCommand
        {
            get => _UseMachineCommand;
            set => SetProperty(ref _UseMachineCommand, value);
        }

        private async void UseMachineCommandExecuted()
        {
            Machine.IUseInterface useInterface = _Machine.Use;

            await useInterface.Use();
            await LoadData();
        }

        private ICommand _GiveBackMachineCommand;
        public ICommand GiveBackMachineCommand
        {
            get => _GiveBackMachineCommand;
            set => SetProperty(ref _GiveBackMachineCommand, value);
        }

        private async void GiveBackMachineCommandExecuted()
        {
            Machine.IInUseInterface inUseInterface = _Machine.Inuse;

            await inUseInterface.GiveBack();
            await LoadData();
        }
        #endregion

        #region INavigationService
        public override void OnNavigatedFrom(INavigationParameters parameters)
        {
            
        }

        public override void OnNavigatedTo(INavigationParameters parameters)
        {
            _Name = parameters["name"] as string;

            IsBusy = true;
            Task.Run(LoadData);
        }
        #endregion
    }
}
