﻿using Borepin.ViewModel;
using Prism.Mvvm;
using System.Collections.Generic;
using System.Threading.Tasks;
using System.Linq;
using Borepin.Model;
using System.Windows.Input;
using Prism.Commands;
using Prism.Navigation;
using Borepin.Service.Connections;
using Borepin.Service.BFFH;
using Borepin.Base;

namespace Borepin.PageModel
{
    public class ServerListPageModel : PageModelBase
    {
        #region Private Properties
        private readonly IConnectionService _ConnectionService;
        private readonly IBFFHService _BFFHService;
        #endregion

        #region Constructors
        public ServerListPageModel(INavigationService navigationService, IConnectionService connectionService, IBFFHService bffhService) : base(navigationService)
        {
            _ConnectionService = connectionService;
            _BFFHService = bffhService;

            AddInstancesCommand = new DelegateCommand(AddInstancesCommandExecuted);
            SelectInstanceCommand = new DelegateCommand<object>(SelectInstanceCommandExecuted);
        }
        #endregion

        #region LoadData
        public override async Task LoadData()
        {
            IsBusy = true;

            List<Connection> list = await _ConnectionService.GetConnectionList();
            if (_BFFHService.ActiveConnection != null)
            {
                ActiveConnection = new List<ServerListItemViewModel>
                {
                    new ServerListItemViewModel(_BFFHService.ActiveConnection)
                };

                list.Remove(_BFFHService.ActiveConnection);

                HasActiveConnection = true;
            }
            else
            {
                HasActiveConnection = false;
            }

            ServerListItemViewModel_List = list.Select(x => new ServerListItemViewModel(x)).ToList();

            IsBusy = false;
        }
        #endregion

        #region Properties
        private List<ServerListItemViewModel> _ServerListItemViewModel_List;
        public List<ServerListItemViewModel> ServerListItemViewModel_List
        {
            get => _ServerListItemViewModel_List;
            set => SetProperty(ref _ServerListItemViewModel_List, value);
        }

        private List<ServerListItemViewModel> _ActiveConnection;
        public List<ServerListItemViewModel> ActiveConnection
        {
            get => _ActiveConnection;
            set => SetProperty(ref _ActiveConnection, value);
        }

        private bool _HasActiveConnection = false;
        public bool HasActiveConnection
        {
            get => _HasActiveConnection;
            set => SetProperty(ref _HasActiveConnection, value);
        }
        #endregion

        #region Commands
        private ICommand _SelectInstanceCommand;
        public ICommand SelectInstanceCommand
        {
            get => _SelectInstanceCommand;
            set => SetProperty(ref _SelectInstanceCommand, value);
        }
        private async void SelectInstanceCommandExecuted(object obj)
        {
            ServerListItemViewModel viewmodel = obj as ServerListItemViewModel;

            NavigationParameters parameters = new NavigationParameters
            {
                { "instance", viewmodel.Instance }
            };

            INavigationResult result = await _NavigationService.NavigateAsync($"ServerPage", parameters);
            if (!result.Success)
            {
                System.Diagnostics.Debugger.Break();
            }
        }

        private ICommand _AddInstancesCommand;
        public ICommand AddInstancesCommand
        {
            get => _AddInstancesCommand;
            set => SetProperty(ref _AddInstancesCommand, value);
        }
        private async void AddInstancesCommandExecuted()
        {
            INavigationResult result = await _NavigationService.NavigateAsync("AddServerProcess_HostSelectPage");
            if (!result.Success)
            {
                System.Diagnostics.Debugger.Break();
            }
        }
        #endregion

        #region INavigationAware
        public override void OnNavigatedFrom(INavigationParameters parameters)
        {

        }

        public override void OnNavigatedTo(INavigationParameters parameters)
        {
            IsBusy = true;
            Task.Run(LoadData);
        }
        #endregion
    }
}
